@@ -2,8 +2,10 @@
 
 # Don't trace to avoid secrets showing up in the logs
 set -o errexit
+set +x
 
 echo "Running enterprise authentication tests"
+source ./secrets-export.sh
 
 export DB_USER="bob"
 export DB_PASSWORD="pwd123"
@@ -23,7 +25,6 @@ export GSSAPI_PORT=${SASL_PORT}
 export GSSAPI_PRINCIPAL=${PRINCIPAL}
 
 # Pass needed env variables to the test environment.
-export TOX_TESTENV_PASSENV=*
+export TOX_ENV="enterprise-synchro"
 
-# --sitepackages allows use of pykerberos without a test dep.
-/opt/python/3.6/bin/python3 -m tox -e "$TOX_ENV" --sitepackages -- -x test.test_auth
+bash ${PROJECT_DIRECTORY}/.evergreen/run-tox.sh
