@@ -16,30 +16,33 @@
 
 See "Frameworks" in the Developer Guide.
 """
-
-
 import asyncio
 import asyncio.tasks
 import functools
 import multiprocessing
 import os
 import warnings
-
-from asyncio import coroutine  # For framework interface.
+from asyncio import get_event_loop  # noqa: F401 - For framework interface.
 from concurrent.futures import ThreadPoolExecutor
 
+# mypy: ignore-errors
 
 try:
     import contextvars
 except ImportError:
     contextvars = None
 
+try:
+    from asyncio import coroutine
+except ImportError:
 
-CLASS_PREFIX = 'AsyncIO'
+    def coroutine():
+        raise RuntimeError(
+            "The coroutine decorator was removed in Python 3.11.  Use 'async def' instead"
+        )
 
 
-def get_event_loop():
-    return asyncio.get_event_loop()
+CLASS_PREFIX = "AsyncIO"
 
 
 def is_event_loop(loop):
@@ -48,30 +51,38 @@ def is_event_loop(loop):
 
 def check_event_loop(loop):
     if not is_event_loop(loop):
-        raise TypeError(
-            "io_loop must be instance of asyncio-compatible event loop,"
-            "not %r" % loop)
+        raise TypeError("io_loop must be instance of asyncio-compatible event loop, not %r" % loop)
 
 
 def get_future(loop):
     return loop.create_future()
 
 
-if 'MOTOR_MAX_WORKERS' in os.environ:
-    max_workers = int(os.environ['MOTOR_MAX_WORKERS'])
+if "MOTOR_MAX_WORKERS" in os.environ:
+    max_workers = int(os.environ["MOTOR_MAX_WORKERS"])
 else:
     max_workers = multiprocessing.cpu_count() * 5
 
 _EXECUTOR = ThreadPoolExecutor(max_workers=max_workers)
 
 
+def _reset_global_executor():
+    """Re-initialize the global ThreadPoolExecutor"""
+    global _EXECUTOR  # noqa: PLW0603
+    _EXECUTOR = ThreadPoolExecutor(max_workers=max_workers)
+
+
+if hasattr(os, "register_at_fork"):
+    # We need this to make sure that creating new clients in subprocesses doesn't deadlock.
+    os.register_at_fork(after_in_child=_reset_global_executor)
+
+
 def run_on_executor(loop, fn, *args, **kwargs):
     if contextvars:
         context = contextvars.copy_context()
         fn = functools.partial(context.run, fn)
 
-    return loop.run_in_executor(
-        _EXECUTOR, functools.partial(fn, *args, **kwargs))
+    return loop.run_in_executor(_EXECUTOR, functools.partial(fn, *args, **kwargs))
 
 
 # Adapted from tornado.gen.
@@ -107,8 +118,7 @@ def chain_return_value(future, loop, return_value):
         else:
             chained.set_result(return_value)
 
-    future.add_done_callback(
-        functools.partial(loop.call_soon_threadsafe, copy))
+    future.add_done_callback(functools.partial(loop.call_soon_threadsafe, copy))
     return chained
 
 
@@ -124,8 +134,7 @@ def call_soon(loop, callback, *args, **kwargs):
 
 
 def add_future(loop, future, callback, *args):
-    future.add_done_callback(
-        functools.partial(loop.call_soon_threadsafe, callback, *args))
+    future.add_done_callback(functools.partial(loop.call_soon_threadsafe, callback, *args))
 
 
 def pymongo_class_wrapper(f, pymongo_class):
@@ -133,6 +142,7 @@ def pymongo_class_wrapper(f, pymongo_class):
 
     See WrapAsync.
     """
+
     @functools.wraps(f)
     async def _wrapper(self, *args, **kwargs):
         result = await f(self, *args, **kwargs)
@@ -149,10 +159,12 @@ def pymongo_class_wrapper(f, pymongo_class):
 
 def yieldable(future):
     warnings.warn(
-        "The yieldable function is deprecated and will be removed in "
-        "Motor 3.0", DeprecationWarning, stacklevel=2)
+        "The yieldable function is deprecated and may be removed in a future major release",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     return next(iter(future))
 
 
 def platform_info():
-    return 'asyncio'
+    return "asyncio"
