@@ -207,6 +207,16 @@ excluded_tests = [
     # Motor does not allow calling to_list on a tailable cursor.
     "TestCursor.test_max_await_time_ms",
     "TestCursor.test_to_list_tailable",
+    # Newer tests not implemented in Motor
+    "TestClient.test_repr_srv_host",
+    "TestGridfs.test_delete_by_name",
+    "TestGridfs.test_rename_by_name",
+    "TestGridfsDeleteByName.*",
+    "TestGridfsRenameByName.*",
+    "TestMongosAndReadPreference.test_read_preference_hedge_deprecated",
+    "TestUnifiedTestFormatValidPassKmsProvidersExplicitKmsCredentials.*",
+    "TestUnifiedTestFormatValidPassKmsProvidersMixedKmsCredentialFields.*",
+    "TestUnifiedTestFormatValidPassKmsProvidersPlaceholderKmsCredentials.*",
 ]
 
 
@@ -333,7 +343,7 @@ if __name__ == "__main__":
         "pymongo.encryption_options",
         "pymongo.mongo_client",
         "pymongo.database",
-        "pymongo.srv_resolver",
+        "pymongo.synchronous.srv_resolver",
         "pymongo.synchronous.collection",
         "pymongo.synchronous.client_session",
         "pymongo.synchronous.command_cursor",
@@ -356,8 +366,12 @@ if __name__ == "__main__":
 
     # Run the tests from the pymongo target dir with our custom plugin.
     os.chdir(sys.argv[1])
+    if "-m" in sys.argv[2:]:
+        markers = []
+    else:
+        markers = ["-m", "default"]
     code = pytest.main(
-        sys.argv[2:] + ["-m", "default"] + ["-p", "no:warnings"], plugins=[SynchroPytestPlugin()]
+        sys.argv[2:] + markers + ["-p", "no:warnings"], plugins=[SynchroPytestPlugin()]
     )
 
     if code != 0:
