@@ -31,9 +31,11 @@ motor_only = set(["delegate", "get_io_loop", "io_loop", "wrap"])
 
 pymongo_only = set(["next"])
 
+pymongo_gridfs_only = set(["delete_by_name", "rename_by_name"])
+
 motor_client_only = motor_only.union(["open"])
 
-pymongo_client_only = set([]).union(pymongo_only)
+pymongo_client_only = set(["eq_props"]).union(pymongo_only)
 
 pymongo_database_only = set([]).union(pymongo_only)
 
@@ -113,7 +115,7 @@ class MotorCoreTestGridFS(MotorTest):
         motor_gridfs_only = set(["collection"]).union(motor_only)
 
         self.assertEqual(
-            attrs(GridFSBucket(env.sync_cx.test)),
+            attrs(GridFSBucket(env.sync_cx.test)) - pymongo_gridfs_only,
             attrs(MotorGridFSBucket(self.cx.test)) - motor_gridfs_only,
         )
 
