@@ -19,21 +19,15 @@ try:
 except ImportError:
     ssl = None
 
-try:
-    # Python 2.
-    from urllib import quote_plus
-except ImportError:
-    # Python 3.
-    from urllib.parse import quote_plus
+import test
+from test import SkipTest
+from test.test_environment import CA_PEM, CLIENT_PEM, env
+from test.tornado_tests import MotorTest
 
 from pymongo.errors import ConfigurationError, ConnectionFailure
 from tornado.testing import gen_test
 
 import motor
-import test
-from test import SkipTest
-from test.tornado_tests import MotorTest
-from test.test_environment import CA_PEM, CLIENT_PEM, env
 
 # Start a mongod instance like:
 #
@@ -55,16 +49,13 @@ class MotorSSLTest(MotorTest):
         super().setUp()
 
     def test_config_ssl(self):
-        self.assertRaises(ValueError, motor.MotorClient, ssl='foo')
-        self.assertRaises(ConfigurationError,
-                          motor.MotorClient,
-                          ssl=False,
-                          ssl_certfile=CLIENT_PEM)
+        self.assertRaises(ValueError, motor.MotorClient, tls="foo")
+        self.assertRaises(
+            ConfigurationError, motor.MotorClient, tls=False, tlsCertificateKeyFile=CLIENT_PEM
+        )
 
-        self.assertRaises(IOError, motor.MotorClient, ssl_certfile="NoFile")
-        self.assertRaises(TypeError, motor.MotorClient, ssl_certfile=True)
-        self.assertRaises(IOError, motor.MotorClient, ssl_keyfile="NoFile")
-        self.assertRaises(TypeError, motor.MotorClient, ssl_keyfile=True)
+        self.assertRaises(IOError, motor.MotorClient, tlsCertificateKeyFile="NoFile")
+        self.assertRaises(TypeError, motor.MotorClient, tlsCertificateKeyFile=True)
 
     @gen_test
     async def test_cert_ssl(self):
@@ -74,16 +65,18 @@ class MotorSSLTest(MotorTest):
         if test.env.auth:
             raise SkipTest("can't test with auth")
 
-        client = motor.MotorClient(env.host, env.port,
-                                   ssl_certfile=CLIENT_PEM,
-                                   ssl_ca_certs=CA_PEM,
-                                   io_loop=self.io_loop)
+        client = motor.MotorClient(
+            env.host,
+            env.port,
+            tlsCertificateKeyFile=CLIENT_PEM,
+            tlsCAFile=CA_PEM,
+            io_loop=self.io_loop,
+        )
 
         await client.db.collection.find_one()
-        response = await client.admin.command('ismaster')
-        if 'setName' in response:
-            client = self.motor_rsc(ssl_certfile=CLIENT_PEM,
-                                    ssl_ca_certs=CA_PEM)
+        response = await client.admin.command("ismaster")
+        if "setName" in response:
+            client = self.motor_rsc(tlsCertificateKeyFile=CLIENT_PEM, tlsCAFile=CA_PEM)
             await client.db.collection.find_one()
 
     @gen_test
@@ -95,23 +88,25 @@ class MotorSSLTest(MotorTest):
             raise SkipTest("can't test with auth")
 
         client = motor.MotorClient(
-            env.host, env.port,
-            ssl_certfile=CLIENT_PEM,
-            ssl_cert_reqs=ssl.CERT_REQUIRED,
-            ssl_ca_certs=CA_PEM,
-            io_loop=self.io_loop)
+            env.host,
+            env.port,
+            tlsCertificateKeyFile=CLIENT_PEM,
+            tlsCAFile=CA_PEM,
+            io_loop=self.io_loop,
+        )
 
         await client.db.collection.find_one()
-        response = await client.admin.command('ismaster')
+        response = await client.admin.command("ismaster")
 
-        if 'setName' in response:
+        if "setName" in response:
             client = motor.MotorClient(
-                env.host, env.port,
-                replicaSet=response['setName'],
-                ssl_certfile=CLIENT_PEM,
-                ssl_cert_reqs=ssl.CERT_REQUIRED,
-                ssl_ca_certs=CA_PEM,
-                io_loop=self.io_loop)
+                env.host,
+                env.port,
+                replicaSet=response["setName"],
+                tlsCertificateKeyFile=CLIENT_PEM,
+                tlsCAFile=CA_PEM,
+                io_loop=self.io_loop,
+            )
 
             await client.db.collection.find_one()
 
@@ -125,12 +120,13 @@ class MotorSSLTest(MotorTest):
 
         client = motor.MotorClient(
             test.env.fake_hostname_uri,
-            ssl_certfile=CLIENT_PEM,
-            ssl_cert_reqs=ssl.CERT_NONE,
-            ssl_ca_certs=CA_PEM,
-            io_loop=self.io_loop)
+            tlsCertificateKeyFile=CLIENT_PEM,
+            tlsAllowInvalidCertificates=True,
+            tlsCAFile=CA_PEM,
+            io_loop=self.io_loop,
+        )
 
-        await client.admin.command('ismaster')
+        await client.admin.command("ismaster")
 
     @gen_test
     async def test_cert_ssl_validation_hostname_fail(self):
@@ -141,34 +137,36 @@ class MotorSSLTest(MotorTest):
             raise SkipTest("can't test with auth")
 
         client = motor.MotorClient(
-            env.host, env.port,
-            ssl_certfile=CLIENT_PEM,
-            ssl_ca_certs=CA_PEM,
-            io_loop=self.io_loop)
+            env.host,
+            env.port,
+            tlsCertificateKeyFile=CLIENT_PEM,
+            tlsCAFile=CA_PEM,
+            io_loop=self.io_loop,
+        )
 
-        response = await client.admin.command('ismaster')
+        response = await client.admin.command("ismaster")
         with self.assertRaises(ConnectionFailure):
             # Create client with hostname 'server', not 'localhost',
             # which is what the server cert presents.
             client = motor.MotorClient(
                 test.env.fake_hostname_uri,
                 serverSelectionTimeoutMS=100,
-                ssl_certfile=CLIENT_PEM,
-                ssl_cert_reqs=ssl.CERT_REQUIRED,
-                ssl_ca_certs=CA_PEM,
-                io_loop=self.io_loop)
+                tlsCertificateKeyFile=CLIENT_PEM,
+                tlsCAFile=CA_PEM,
+                io_loop=self.io_loop,
+            )
 
             await client.db.collection.find_one()
 
-        if 'setName' in response:
+        if "setName" in response:
             with self.assertRaises(ConnectionFailure):
                 client = motor.MotorClient(
                     test.env.fake_hostname_uri,
                     serverSelectionTimeoutMS=100,
-                    replicaSet=response['setName'],
-                    ssl_certfile=CLIENT_PEM,
-                    ssl_cert_reqs=ssl.CERT_REQUIRED,
-                    ssl_ca_certs=CA_PEM,
-                    io_loop=self.io_loop)
+                    replicaSet=response["setName"],
+                    tlsCertificateKeyFile=CLIENT_PEM,
+                    tlsCAFile=CA_PEM,
+                    io_loop=self.io_loop,
+                )
 
                 await client.db.collection.find_one()
