@@ -15,7 +15,7 @@
 from collections import defaultdict
 
 from bson import SON
-from pymongo import monitoring
+from pymongo import common, monitoring
 
 """Utilities for testing Motor with any framework."""
 
@@ -28,6 +28,9 @@ import warnings
 # mypy: ignore-errors
 
 
+AUTO_ISMASTER = {"maxWireVersion": common.MIN_SUPPORTED_WIRE_VERSION}
+
+
 def one(s):
     """Get one element of a set"""
     return next(iter(s))
